/*
 * (c) Bernd Müller & Harald Wehr, www.jpainfo.de
 */
package de.jpainfo.model;

import java.math.BigDecimal;
import java.util.Collections;
import java.util.HashSet;
import java.util.Set;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.OneToMany;

import static de.jpainfo.model.Buchungsart.*;

@Entity
public class Konto {

	@Id 
	@GeneratedValue
	private Integer kontonummer;
	@Column(precision = 10, scale = 2)
	private BigDecimal kontostand;
	
	//@OneToMany(cascade = CascadeType.ALL)
	//@OneToMany(mappedBy = "konto", cascade = CascadeType.ALL, orphanRemoval = true, fetch = FetchType.LAZY)
	@OneToMany(mappedBy = "konto", cascade = CascadeType.ALL, orphanRemoval = true)
	private Set<Buchung> buchungen;
	
	public Konto() {
		kontostand = BigDecimal.ZERO.setScale(2);
		buchungen = new HashSet<Buchung>();
	}

	public void addBuchung(Buchung buchung) {
		buchung.setKonto(this);
		buchungen.add(buchung);
		if (buchung.getBuchungsart() == HABEN) {
			kontostand = kontostand.add(buchung.getBetrag());
		} else if (buchung.getBuchungsart() == SOLL) {
			kontostand = kontostand.subtract(buchung.getBetrag());
		} else {
			throw new RuntimeException("Buchungsart muss bekannt sein.");
		}
	}
	
	public void deleteBuchung(Buchung buchung) {
		// schlecher Use-Case: soll Betrag rückgebucht werden?
		buchungen.remove(buchung);
	}
	
	
	// Getter und Setter
	public Integer getKontonummer() {
		return kontonummer;
	}

	public BigDecimal getKontostand() {
		return kontostand;
	}

	public Set<Buchung> getBuchungen() {
		return Collections.unmodifiableSet(buchungen);
	}

	
}
